==> odata-client-microsoft-dynamics-0.1.38-sources.jar: microsoft/dynamics/crm/entity/collection/request/StagesolutionuploadCollectionRequest.java <==
package microsoft.dynamics.crm.entity.collection.request;

import com.github.davidmoten.odata.client.CollectionPageEntityRequest;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.NameValue;
import com.github.davidmoten.odata.client.internal.RequestHelper;

import java.lang.Object;
import java.lang.String;
import java.util.Optional;

import microsoft.dynamics.crm.entity.Stagesolutionupload;
import microsoft.dynamics.crm.entity.request.AsyncoperationRequest;
import microsoft.dynamics.crm.entity.request.BulkdeletefailureRequest;
import microsoft.dynamics.crm.entity.request.DuplicaterecordRequest;
import microsoft.dynamics.crm.entity.request.FileattachmentRequest;
import microsoft.dynamics.crm.entity.request.MailboxtrackingfolderRequest;
import microsoft.dynamics.crm.entity.request.PrincipalobjectattributeaccessRequest;
import microsoft.dynamics.crm.entity.request.ProcesssessionRequest;
import microsoft.dynamics.crm.entity.request.StagesolutionuploadRequest;
import microsoft.dynamics.crm.entity.request.SyncerrorRequest;
import microsoft.dynamics.crm.schema.SchemaInfo;

public class StagesolutionuploadCollectionRequest extends CollectionPageEntityRequest<Stagesolutionupload, StagesolutionuploadRequest>{

    protected ContextPath contextPath;

    public StagesolutionuploadCollectionRequest(ContextPath contextPath, Optional<Object> value) {
        super(contextPath, Stagesolutionupload.class, cp -> new StagesolutionuploadRequest(cp, Optional.empty()), SchemaInfo.INSTANCE, value);
        this.contextPath = contextPath;
    }

    public SyncerrorCollectionRequest stagesolutionupload_SyncErrors() {
        return new SyncerrorCollectionRequest(contextPath.addSegment("stagesolutionupload_SyncErrors"), Optional.empty());
    }

    public SyncerrorRequest stagesolutionupload_SyncErrors(String syncerrorid) {
        return new SyncerrorRequest(contextPath.addSegment("stagesolutionupload_SyncErrors").addKeys(new NameValue(syncerrorid.toString())), Optional.empty());
    }

    public DuplicaterecordCollectionRequest stagesolutionupload_DuplicateMatchingRecord() {
        return new DuplicaterecordCollectionRequest(contextPath.addSegment("stagesolutionupload_DuplicateMatchingRecord"), Optional.empty());
    }

    public DuplicaterecordRequest stagesolutionupload_DuplicateMatchingRecord(String duplicateid) {
        return new DuplicaterecordRequest(contextPath.addSegment("stagesolutionupload_DuplicateMatchingRecord").addKeys(new NameValue(duplicateid.toString())), Optional.empty());
    }

    public DuplicaterecordCollectionRequest stagesolutionupload_DuplicateBaseRecord() {
        return new DuplicaterecordCollectionRequest(contextPath.addSegment("stagesolutionupload_DuplicateBaseRecord"), Optional.empty());
    }

    public DuplicaterecordRequest stagesolutionupload_DuplicateBaseRecord(String duplicateid) {
        return new DuplicaterecordRequest(contextPath.addSegment("stagesolutionupload_DuplicateBaseRecord").addKeys(new NameValue(duplicateid.toString())), Optional.empty());
    }

    public AsyncoperationCollectionRequest stagesolutionupload_AsyncOperations() {
        return new AsyncoperationCollectionRequest(contextPath.addSegment("stagesolutionupload_AsyncOperations"), Optional.empty());
    }

    public AsyncoperationRequest stagesolutionupload_AsyncOperations(String asyncoperationid) {
        return new AsyncoperationRequest(contextPath.addSegment("stagesolutionupload_AsyncOperations").addKeys(new NameValue(asyncoperationid.toString())), Optional.empty());
    }

    public MailboxtrackingfolderCollectionRequest stagesolutionupload_MailboxTrackingFolders() {
        return new MailboxtrackingfolderCollectionRequest(contextPath.addSegment("stagesolutionupload_MailboxTrackingFolders"), Optional.empty());
    }

    public MailboxtrackingfolderRequest stagesolutionupload_MailboxTrackingFolders(String mailboxtrackingfolderid) {
        return new MailboxtrackingfolderRequest(contextPath.addSegment("stagesolutionupload_MailboxTrackingFolders").addKeys(new NameValue(mailboxtrackingfolderid.toString())), Optional.empty());
    }

    public ProcesssessionCollectionRequest stagesolutionupload_ProcessSession() {
        return new ProcesssessionCollectionRequest(contextPath.addSegment("stagesolutionupload_ProcessSession"), Optional.empty());
    }

    public ProcesssessionRequest stagesolutionupload_ProcessSession(String processsessionid) {
        return new ProcesssessionRequest(contextPath.addSegment("stagesolutionupload_ProcessSession").addKeys(new NameValue(processsessionid.toString())), Optional.empty());
    }

    public BulkdeletefailureCollectionRequest stagesolutionupload_BulkDeleteFailures() {
        return new BulkdeletefailureCollectionRequest(contextPath.addSegment("stagesolutionupload_BulkDeleteFailures"), Optional.empty());
    }

    public BulkdeletefailureRequest stagesolutionupload_BulkDeleteFailures(String bulkdeletefailureid) {
        return new BulkdeletefailureRequest(contextPath.addSegment("stagesolutionupload_BulkDeleteFailures").addKeys(new NameValue(bulkdeletefailureid.toString())), Optional.empty());
    }

    public PrincipalobjectattributeaccessCollectionRequest stagesolutionupload_PrincipalObjectAttributeAccesses() {
        return new PrincipalobjectattributeaccessCollectionRequest(contextPath.addSegment("stagesolutionupload_PrincipalObjectAttributeAccesses"), Optional.empty());
    }

    public PrincipalobjectattributeaccessRequest stagesolutionupload_PrincipalObjectAttributeAccesses(String principalobjectattributeaccessid) {
        return new PrincipalobjectattributeaccessRequest(contextPath.addSegment("stagesolutionupload_PrincipalObjectAttributeAccesses").addKeys(new NameValue(principalobjectattributeaccessid.toString())), Optional.empty());
    }

    public FileattachmentCollectionRequest stagesolutionupload_FileAttachments() {
        return new FileattachmentCollectionRequest(contextPath.addSegment("stagesolutionupload_FileAttachments"), Optional.empty());
    }

    public FileattachmentRequest stagesolutionupload_FileAttachments(String fileattachmentid) {
        return new FileattachmentRequest(contextPath.addSegment("stagesolutionupload_FileAttachments").addKeys(new NameValue(fileattachmentid.toString())), Optional.empty());
    }

}

==> odata-client-microsoft-dynamics-0.1.39-sources.jar: microsoft/dynamics/crm/entity/collection/request/StagesolutionuploadCollectionRequest.java <==
package microsoft.dynamics.crm.entity.collection.request;

import com.github.davidmoten.odata.client.CollectionPageEntityRequest;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.NameValue;
import com.github.davidmoten.odata.client.internal.RequestHelper;

import java.lang.Object;
import java.lang.String;
import java.util.Optional;

import microsoft.dynamics.crm.entity.Stagesolutionupload;
import microsoft.dynamics.crm.entity.request.AsyncoperationRequest;
import microsoft.dynamics.crm.entity.request.BulkdeletefailureRequest;
import microsoft.dynamics.crm.entity.request.DuplicaterecordRequest;
import microsoft.dynamics.crm.entity.request.FileattachmentRequest;
import microsoft.dynamics.crm.entity.request.MailboxtrackingfolderRequest;
import microsoft.dynamics.crm.entity.request.PrincipalobjectattributeaccessRequest;
import microsoft.dynamics.crm.entity.request.ProcesssessionRequest;
import microsoft.dynamics.crm.entity.request.StagesolutionuploadRequest;
import microsoft.dynamics.crm.entity.request.SyncerrorRequest;

public class StagesolutionuploadCollectionRequest extends CollectionPageEntityRequest<Stagesolutionupload, StagesolutionuploadRequest>{

    protected ContextPath contextPath;

    public StagesolutionuploadCollectionRequest(ContextPath contextPath, Optional<Object> value) {
        super(contextPath, Stagesolutionupload.class, cp -> new StagesolutionuploadRequest(cp, Optional.empty()), value);
        this.contextPath = contextPath;
    }

    public SyncerrorCollectionRequest stagesolutionupload_SyncErrors() {
        return new SyncerrorCollectionRequest(contextPath.addSegment("stagesolutionupload_SyncErrors"), Optional.empty());
    }

    public SyncerrorRequest stagesolutionupload_SyncErrors(String syncerrorid) {
        return new SyncerrorRequest(contextPath.addSegment("stagesolutionupload_SyncErrors").addKeys(new NameValue(syncerrorid.toString())), Optional.empty());
    }

    public DuplicaterecordCollectionRequest stagesolutionupload_DuplicateMatchingRecord() {
        return new DuplicaterecordCollectionRequest(contextPath.addSegment("stagesolutionupload_DuplicateMatchingRecord"), Optional.empty());
    }

    public DuplicaterecordRequest stagesolutionupload_DuplicateMatchingRecord(String duplicateid) {
        return new DuplicaterecordRequest(contextPath.addSegment("stagesolutionupload_DuplicateMatchingRecord").addKeys(new NameValue(duplicateid.toString())), Optional.empty());
    }

    public DuplicaterecordCollectionRequest stagesolutionupload_DuplicateBaseRecord() {
        return new DuplicaterecordCollectionRequest(contextPath.addSegment("stagesolutionupload_DuplicateBaseRecord"), Optional.empty());
    }

    public DuplicaterecordRequest stagesolutionupload_DuplicateBaseRecord(String duplicateid) {
        return new DuplicaterecordRequest(contextPath.addSegment("stagesolutionupload_DuplicateBaseRecord").addKeys(new NameValue(duplicateid.toString())), Optional.empty());
    }

    public AsyncoperationCollectionRequest stagesolutionupload_AsyncOperations() {
        return new AsyncoperationCollectionRequest(contextPath.addSegment("stagesolutionupload_AsyncOperations"), Optional.empty());
    }

    public AsyncoperationRequest stagesolutionupload_AsyncOperations(String asyncoperationid) {
        return new AsyncoperationRequest(contextPath.addSegment("stagesolutionupload_AsyncOperations").addKeys(new NameValue(asyncoperationid.toString())), Optional.empty());
    }

    public MailboxtrackingfolderCollectionRequest stagesolutionupload_MailboxTrackingFolders() {
        return new MailboxtrackingfolderCollectionRequest(contextPath.addSegment("stagesolutionupload_MailboxTrackingFolders"), Optional.empty());
    }

    public MailboxtrackingfolderRequest stagesolutionupload_MailboxTrackingFolders(String mailboxtrackingfolderid) {
        return new MailboxtrackingfolderRequest(contextPath.addSegment("stagesolutionupload_MailboxTrackingFolders").addKeys(new NameValue(mailboxtrackingfolderid.toString())), Optional.empty());
    }

    public ProcesssessionCollectionRequest stagesolutionupload_ProcessSession() {
        return new ProcesssessionCollectionRequest(contextPath.addSegment("stagesolutionupload_ProcessSession"), Optional.empty());
    }

    public ProcesssessionRequest stagesolutionupload_ProcessSession(String processsessionid) {
        return new ProcesssessionRequest(contextPath.addSegment("stagesolutionupload_ProcessSession").addKeys(new NameValue(processsessionid.toString())), Optional.empty());
    }

    public BulkdeletefailureCollectionRequest stagesolutionupload_BulkDeleteFailures() {
        return new BulkdeletefailureCollectionRequest(contextPath.addSegment("stagesolutionupload_BulkDeleteFailures"), Optional.empty());
    }

    public BulkdeletefailureRequest stagesolutionupload_BulkDeleteFailures(String bulkdeletefailureid) {
        return new BulkdeletefailureRequest(contextPath.addSegment("stagesolutionupload_BulkDeleteFailures").addKeys(new NameValue(bulkdeletefailureid.toString())), Optional.empty());
    }

    public PrincipalobjectattributeaccessCollectionRequest stagesolutionupload_PrincipalObjectAttributeAccesses() {
        return new PrincipalobjectattributeaccessCollectionRequest(contextPath.addSegment("stagesolutionupload_PrincipalObjectAttributeAccesses"), Optional.empty());
    }

    public PrincipalobjectattributeaccessRequest stagesolutionupload_PrincipalObjectAttributeAccesses(String principalobjectattributeaccessid) {
        return new PrincipalobjectattributeaccessRequest(contextPath.addSegment("stagesolutionupload_PrincipalObjectAttributeAccesses").addKeys(new NameValue(principalobjectattributeaccessid.toString())), Optional.empty());
    }

    public FileattachmentCollectionRequest stagesolutionupload_FileAttachments() {
        return new FileattachmentCollectionRequest(contextPath.addSegment("stagesolutionupload_FileAttachments"), Optional.empty());
    }

    public FileattachmentRequest stagesolutionupload_FileAttachments(String fileattachmentid) {
        return new FileattachmentRequest(contextPath.addSegment("stagesolutionupload_FileAttachments").addKeys(new NameValue(fileattachmentid.toString())), Optional.empty());
    }

}
